@@ -6,18 +6,20 @@ from rpy2.rinterface_lib import sexp
 from . import conversion
 
 import rpy2.rlike.container as rlc
-
+import datetime
+try:
+    import zoneinfo  # type: ignore
+except ImportError:
+    from backports import zoneinfo  # type: ignore
 import copy
 import itertools
 import math
 import os
 import jinja2  # type: ignore
 import time
-import pytz
 import tzlocal
-from datetime import date, datetime, timedelta, timezone
-from time import struct_time, mktime, tzname
-from operator import attrgetter
+
+from time import struct_time, mktime
 import typing
 import warnings
 
@@ -872,7 +874,7 @@ class DateVector(FloatVector):
 
         if isinstance(seq, Sexp):
             init_param = seq
-        elif isinstance(seq[0], date):
+        elif isinstance(seq[0], datetime.date):
             init_param = DateVector.sexp_from_date(seq)
         else:
             raise TypeError(
@@ -913,7 +915,7 @@ class POSIXct(POSIXt, FloatVector):
             init_param = seq
         elif isinstance(seq[0], struct_time):
             init_param = POSIXct.sexp_from_struct_time(seq)
-        elif isinstance(seq[0], datetime):
+        elif isinstance(seq[0], datetime.datetime):
             init_param = POSIXct.sexp_from_datetime(seq)
         else:
             raise TypeError(
@@ -944,7 +946,7 @@ class POSIXct(POSIXt, FloatVector):
                 )
 
         if tz_info is None:
-            tz_info = tzname[0]
+            tz_info = default_timezone if default_timezone else ''
         # We could use R's as.POSIXct instead of ISOdatetime
         # since as.POSIXct is used by it anyway, but the overall
         # interface for dates and conversion between formats
@@ -952,7 +954,10 @@ class POSIXct(POSIXt, FloatVector):
         # time should look into this.
 
         d = isodatetime_columns(seq)
-        sexp = POSIXct._ISOdatetime(*d, tz=StrSexpVector((tz_info, )))
+        sexp = POSIXct._ISOdatetime(
+            *d,
+            tz=StrSexpVector((str(tz_info), ))
+        )
         return sexp
 
     @staticmethod
@@ -964,7 +969,7 @@ class POSIXct(POSIXt, FloatVector):
                     IntVector([x.tm_hour for x in seq]),
                     IntVector([x.tm_min for x in seq]),
                     IntVector([x.tm_sec for x in seq])]
-        return POSIXct._sexp_from_seq(seq, lambda elt: time.tzname[0], f)
+        return POSIXct._sexp_from_seq(seq, lambda elt: elt.tm_zone, f)
 
     @staticmethod
     def sexp_from_datetime(seq):
@@ -978,7 +983,10 @@ class POSIXct(POSIXt, FloatVector):
                     IntVector([x.minute for x in seq]),
                     IntVector([x.second for x in seq])]
 
-        return POSIXct._sexp_from_seq(seq, attrgetter('tzinfo'), f)
+        def get_tz(elt):
+            return elt.tzinfo if elt.tzinfo else None
+
+        return POSIXct._sexp_from_seq(seq, get_tz, f)
 
     @staticmethod
     def isrinstance(obj) -> bool:
@@ -986,13 +994,13 @@ class POSIXct(POSIXt, FloatVector):
         return obj.rclass[0] == 'POSIXct'
 
     @staticmethod
-    def _datetime_from_timestamp(ts, tz) -> datetime:
+    def _datetime_from_timestamp(ts, tz) -> datetime.datetime:
         """Platform-dependent conversion from timestamp to datetime"""
         if os.name != 'nt' or ts > 0:
-            return datetime.fromtimestamp(ts, tz)
+            return datetime.datetime.fromtimestamp(ts, tz)
         else:
-            dt_utc = (datetime(1970, 1, 1, tzinfo=timezone.utc) +
-                      timedelta(seconds=ts))
+            dt_utc = (datetime.datetime(1970, 1, 1, tzinfo=datetime.timezone.utc) +
+                      datetime.timedelta(seconds=ts))
             dt = dt_utc.replace(tzinfo=tz)
             offset = dt.utcoffset()
             if offset is None:
@@ -1013,8 +1021,7 @@ class POSIXct(POSIXt, FloatVector):
             # time libraries will assume UTC.
             r_tzone = get_timezone()
         else:
-            r_tzone = pytz.timezone(r_tzone_name)
-
+            r_tzone = zoneinfo.ZoneInfo(r_tzone_name)
         for x in self:
             yield (
                 None if math.isnan(x)
@@ -1262,7 +1269,7 @@ class DataFrame(ListVector):
         if isinstance(obj, rinterface.ListSexpVector):
             if obj.typeof != rinterface.RTYPES.VECSXP:
                 raise ValueError(
-                    "obj should of typeof RTYPES.VECSXP "
+                    "obj should be of typeof RTYPES.VECSXP "
                     " (and we get %s)" % rinterface.RTYPES(obj.typeof)
                 )
             if (
@@ -1374,7 +1381,7 @@ class DataFrame(ListVector):
 
     def _get_colnames(self):
         res = baseenv_ri["colnames"](self)
-        return conversion.rpy2py(res)
+        return conversion.get_conversion().rpy2py(res)
 
     def _set_colnames(self, colnames):
         res = baseenv_ri["colnames<-"](
